---
layout: default
warning: draft
---

<h1> Welcome to Class! </h1>
How can computing enable new solutions to accessibility, including both access to the world and access to computers? Similarly, how can a disability studies perspective guide us in developing empowering and relevant solutions to accessibility problems? This course explores both of those questions through a combination of discussions, reading, and building.

Access technology (AT) has the potential to increase autonomy, and improve millions of people’s ability to live independently. This potential is currently under-realized because the expertise needed to create the right AT is in short supply and the custom nature of AT makes it difficult to deliver inexpensively. Yet computers’ flexibility and exponentially increasing power have revolutionized and democratized access technologies. In addition, by studying access technology, we can gain valuable insights into the future of all user interface technology.

In this course we will focus on two primary domains for access technologies: Access to the world (first half of the class) and Access to computers (second half of class). The largest project in the class will be an open ended opportunity to explore access technology in more depth. 

For quick links to key things, check out the navigation bar above and the table of contents here:

* TOC
{:toc}

# Introductory Video

<iframe width="560" height="315" src="https://www.youtube.com/embed/4_jFJcUE9EI" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

# Class Times

See [Canvas]({{site.canvas}}) for all zoom meeting links

**Class Time:** Monday and Wednesday 6:30-7:50PM \\

# Course staff

## Instructor

![Jen Mankoff](assets/img/staff/mankoff.jpg){:width="80px"} | [Jennifer Mankoff]({{site.author.url}}) (she/her) <br>  Office Hours: TBD

## TA

![Venkatesh Potluri](assets/img/staff/potluri.jpg){:class="ta-picture"} | [Venkatesh Potluri](https://venkateshpotluri.me) (he/him)<br/> Office hours: TBD.

(More information on [Pronouns](https://www.mypronouns.org/))

# Should I take this class?

Yes! Everyone planning a career in interactive technology should understand access technology. Not only is it cutting edge and exciting, accessibility is a human rights issue and it is the law. Students of interactive technology should know how to build regular interfaces that are accessible as well as understanding the value of innovating new approaches to accessibility. Disability touches almost everyone either directly or indirectly at some point in life, temporarily or permanently. Let’s create a future we will also want to and be able to be part of.

This class will teach you

- How to make interfaces and interactions accessible.
- How to solve an accessibility problem
- What access technologies already exist. We will find examples, watch people talk about how they use them, and help with or shadow someone using AT (tentative).
- Ways to convince others that accessibility is important
- How to build accessible interfaces. You will make your own webpage accessible.
- Where we came from and where we are going. You will learn about some of the history of access technology, including how they are used, how they are constructed, when and how they were developed/adopted and what might be part of the future of AT.

Taking a class is a big commitment, and you will work hard in this class. So we want to help you make sure this is the right class for you. Below is some information about prerequisites and expectations.


# Prereqs and expectations

The only requirement for this class is that you are comfortable programming and picking up new languages that you have not been exposed to before. You will be expected (with minimal to no specific instruction) to program in Python, Java (Android), work with HTML (and possibly CSS/Javascript).


# Course Structure

Many of the goals in this class center around learning by doing. This means that hands on time trying out everything from implementation to evaluation is critical to learning. To support this, readings and videos will be expected to be viewed/read ahead of class, while class time will be used as much as possible for activities, discussion, review, and homework.


## Zoom

All schedule sessions for this course are scheduled to run **synchronously at your scheduled class time via Zoom**.
These Zoom class sessions **will be recorded**. The recording will capture the presenter’s audio,
video and computer screen. Student audio and video will be recorded if they share their computer
audio and video during the recorded session. The recordings will only be accessible to students
enrolled in the course to review materials. These recordings will **not be shared with or
accessible to the public**.

The University and Zoom have FERPA-compliant agreements in place to protect the security and
privacy of UW Zoom accounts. Students who do not wish to be recorded should:
-Change their Zoom screen name to a school appropriate screen name that hides any personal
identifying information such as their name or
UW Net ID
- Not share their computer audio or video during their Zoom sessions  (please notify us first!).

## Lectures

Lectures are designed to introduce new material throughout the quarter, motivate key theories and
concepts, as well as practice.  

The goals in this class center around learning by doing. This
means that hands on time trying out everything from implementation to
evaluation is critical to learning. Active learning  has been [shown to increase student performance
in STEM subjects](https://www.pnas.org/content/111/23/8410).

Thus, class time will be used as much as possible for in **class exercises and surveys, as well as discussion and review. You will be graded on general participation in lecture** for understanding using a variety of technologies.
We also highly encourage questions in lecture. Often many students share the same question and
those questions can help the instructor gauge student understanding.

### Lecture Readings

Preparation outside of class and participation in class are both very important and will improve
your class experience. The **pre-lecture readings and activities are designed to support your studying
and learning**, particularly as we discuss both theoretical and practical aspects of interface
Programming. Stay on top of the course materials, bring your questions to class and seek help
if there are problems.

### Remote Lecture Guidelines and Expectations
Students are expected to adhere to the below expectations for remote lectures. These guidelines are
intended to help lecture go more smoothly, facilitate questions and group activities, and foster a
sense of community within the class.

- You are **not required to have your video turned on during lecture** except during group activities in breakout rooms
- Please keep your **mic muted unless you’re asking a question**
- To ask a question, please type “hand” in the chat in Zoom. The instructor or moderator will call on
you and then you can unmute your mic and ask your question
- You may also post questions in the chat, but you may be asked to unmute your mic and ask your question aloud
- There will be individual and group based activities which you are expected to participate in (please
  contact the instructor if you not able to participate in the lectures synchronously due to your
  current living situation).
- It may be helpful for some students to see the instructor speaking even when the instructor
 is sharing their screen. 
 - This can be achieved by right clicking the instructor’s video and choosing
 “pin” video. 
 - Then, under “view options” you can choose the side-by-side option which will
 enlarge the instructor video

## Accessibility

Please ensure that your material is accessible to the best of your capabilities. We will offer guidance on this in class, but given that the process of making content accessible heavily depends on the tools you use to author the content, it is practically impossible for us to offer exhaustive guidance. Here are a few resources to get started, but please reach out to us when in doubt.

  - [Accessible PDF author guide](http://www.sigaccess.org/welcome-to-sigaccess/resources/accessible-pdf-author-guide/)
  - [General guidelines to make your presentations accessible](http://www.sigaccess.org/welcome-to-sigaccess/resources/accessible-presentation-guide/).
  - [A paper on making your talk accessible](https://homes.cs.washington.edu/~ladner/MakingYourTalkAccessible.pdf).
  - Instructions to enable closed captions while presenting using [Google Slides](https://support.google.com/docs/answer/9109474?hl=en) and [Microsoft Powerpoint](https://support.microsoft.com/en-us/office/present-with-real-time-automatic-captions-or-subtitles-in-powerpoint-68d20e49-aec3-456a-939d-34a79e8ddd5f)

# Workload

This is a challenging, four credit class, meaning you should expect 8
hours of homework outside of class a week. We hope to make the workload as predictable as
possible.

# Class Coordination

We want you to succeed in this class, and an important way that you do that is by **asking questions and discussing course issues with your peers and teaching staff**. Some ways to do that include:

- We have a class discussion [list]({{site.piazza}}), where you can
  make public posts that benefit the whole class, and are answered more
  quickly because your fellow students can help the course staff by
  responding also. This is the best way to ask questions about things
  like homework. 
- We hold office hours (see above). If none of those times work for
  you. You can also discuss matters with us privately through [canvas]({{site.canvas}}). Using Canvas gets the whole course staff at once and is usually faster than
  email. Lastly, if none of these work for you you can send an email
  asking to set up an appointment.

# Class Expectations

The class is a shared learning environment and it is important it is a welcoming environment for everyone, from all backgrounds. As instructors, we know that students in this class may need materials to be accessible by screen reader, or may need extra time on exams. You may observe religious holidays that overlap class times, or have work, childcare or appointments that have to be prioritized at specific times. As students we also ask you to remember that each person brings different priorities and experiences to class. We should all strive to treat everyone in the class with respect and understanding. Some specific things we
will do to try to make the class a welcoming environment:

- **Accessibility**: We have attempted to make all the course materials
  accessible according to web standards. If you need any additional
  support, we am always happy to work with you and
  [Disability Resources for Students (DRS)](http://depts.washington.edu/uwdrs/)  to make sure
  that the class meets your needs. DRS offers a wide range of services for students with
  disabilities that are individually designed and remove the need to reveal sensitive medical
  information to the course staff, but it is important to start the process as soon as possible to avoid delays. 
- **Inclusivity**: We will be working toward a broad base of examples,
  and a welcoming environment for all. Please let us know if you see
  opportunities to improve this.
- **Working Together**: Working together is encouraged, as
  long as you in the end implement your own code (it is not directly copied from
  another student or any other source on the internet), and make sure to
  document any information you get from other students in comments at
  the top of the relevant file.
- **Integrity**: Academic integrity is an important value that we adhere to in this class.
  Instructors are expected to respect student privacy, and treat students fairly. 
  - Students are expected not to share code/solutions with the broader public, and not to plagiarize or cheat,
  as described in the [Allen school conduct guidelines](https://www.cs.washington.edu/academics/misconduct). 
  - For more details on how this will be implemented in this class, please see the [Academic Conduct](academic-conduct.html) page.
- **Wellness**: Wellness
It is very important to us that you take care of your mental health throughout the course. Everyone on the course staff is available to chat, and you can always attend office hours for a non-academic conversation if necessary. Beyond the course staff, the University of Washington provides the following resources for mental health concerns. Your anonymity and privacy are protected.
  - Please reach out to the [UW Counseling Center](http://www.washington.edu/counseling/) for any help and concerns related to mental health (including increased stress), available to all UW students at no cost.
  - If you are ever feeling uncomfortable and need to talk or are worried about someone close to you, it is highly recommended to visit the [UW Heath and Wellness](http://depts.washington.edu/livewell/programs/) programs. They offer resources to students that can help.
If you're concerned for yourself or a friend, please call SafeCampus at (206) 685-7233.
- **Accessibility**: If you have a temporary health condition or permanent disability (either mental health or physical health related) that impacts your academic experience, please let us know how we can accomodate you. You are NOT obligated to disclose any of these issues with
me, only specify if there’s any accommodations required. I myself have an invisible disability (mostly, sometimes I use a cane) and I understand the importance of an inclusive classroom.
  - If there is something we can do to make your experience better, please let us know. We have attempted to make all the course materials accessible according to web standards but there are always things we may not have thought of. 
  - If you need any additional support, we am always happy to work with you directly or through DRS to make sure
  that the class meets your needs. If you
need any adaptations for course materials (large font, pacing, image description, closed captioning), just let me know. 
  - You may also want to contact [Disability Resources for Students (DRS)](http://depts.washington.edu/uwdrs/) at uwdrs@uw.edu if you have not already.  DRS offers a wide range of services for students with
  disabilities, that are individually designed and remove the need to reveal sensitive medical
  information to the course staff, but it is important to start the process as soon as possible to avoid delays.
- **Religious Accommodations** The UW’s policy, including more information about how to request an accommodation, is available at
[Religious Accommodations Policy](https://registrar.washington.edu/staffandfaculty/religious-accommodations-policy/).
Accommodations can be requested within the first two weeks of this course using the
[Religious Accommodations Request](https://registrar.washington.edu/students/religious-accommodations-request/)
 form on UW's site. 
- **Inclusivity**: We will be working toward a broad base of examples. Please let us know if you see
  opportunities to improve this. Also, we want the classroom to be a welcoming environment for all.  If you experience interactions with anyone that are excluding or otherwise uncomfortable so that we can address and improve.
- **Sexual Harrassment**: University policy prohibits all forms of sexual harassment. 
  - If you feel you have been a victim of sexual harassment or if you feel you have been discriminated against, you may speak with your instructor, teaching assistant, the chair of the department
  - You can also file a complaint with the UW Ombudsman's Office for Sexual Harassment. Their office is located at 339 HUB, (206)543-6028. There is a second office, the University Complaint Investigation and Resolution Office, who also investigate complaints. The UCIRO is located at 22 Gerberding Hall.
  
# Grading

While grading is a necessary part of what we do at UW, I want to focus this class on learning. The following policies are meant to encourage that.

## Grading Approach
We’ll be using approval grading in this class. That means that I will provide a rubric for each assignment, plus a rubric for learning goals for the entire quarter. You’ll fill both out. If you do the things they says, you get the grade.

Rubrics verification will be lightweight verification in class by random classmate, with occasional verification by myself and the TA.

One of the rubrics items for the class will have to do with time management. Turning in homework late will impact your score on that rubric. Part of time management is knowing when something should give. Thus, the time management rubric will include up to 4 penalty-free late days.

## Grading Breakdown (tentative)
Grades will be assigned approximately as follows:

- 10%: Facility in overall learning goals
- 30%: Smaller assignments
- 50%: Large project
- 10%: Effort, participation and altruism

## EPA (Effort, participation and altruism)

You can earn "points" for each of the following:

- **Effort:** Attending office hours, lectures, and sections. Keeping up with the discussions.
- **Participation:** Asking questions in lecture and in online discussions (i.e. our email list). Voting on peer instruction questions, interacting with TAs and other students.
- **Altruism:** Helping others in lecture, during office hours, and online.

EPA scores are kept internal to the staff (i.e. not disclosed to students).

## Sharing and group projects

Working together is encouraged, as long as you in the end implement your own code, and make sure to document any information you get from other students in comments at the top of the relevant file. You will work on one of your projects in pairs.


